/*******************************************************************
REPLICATION FILE FOR:
Paper: "How Talking Across Ethnic and Class Divides Shapes Support for Ethnic Politics"
Authors: Laura Paler, Leslie Marshall, and Sami Atallah

This do file does all cleaning and recoding following the 10 rounds of missing data imputation for the original data (see README).
It also creates all indices used in the analysis using inverse covariance weighting as in
Anderson (2008). It calls the make_index.ado file (written by Cyrus Samii, NYU) to create the indices.
********************************************************************/

*******************************************************
*SET GLOBAL DIRECTORIES
*******************************************************

*Set your personal working directory here: cd~
cd ~/Dropbox/LEBANON/WRITING/2_DISCUSSION/REPLICATION

	global dos "DOs_and_ADOs"
	global packages "DOs_and_ADOs/PACKAGES"

	global data_orig "DATA/ORIG"
	global data_newimp "DATA/NEW_IMPUTE"
	global working "DATA/NEW_IMPUTE/WORKING"

	global results "RESULTS" 
	global results_figs "RESULTS/FIGS"
	global results_tables "RESULTS/TABLES"

	set more off

*Need this to make indices below	
	do "$dos/make_index.ado"

	
*Call the original dataset used in the actual analysis	
	use "$data_orig/Leb_2_Impute_FINAL_Orig.dta", clear

*******************************************************
*KEEP ONLY VARS USED IN ANALYSIS
*******************************************************

keep set gid pid ses sect strata_final treat_prob T_mixed_sect T_mixed_class ///
		strata_agg_FINAL2 strata_agg_FINAL final_assign ///
		scr_q8_sect scr_recruiter_id ///
		scr_q1_gender scr_q2_age scr_q3_marital scr_q4_educ scr_q6_work ///
		scr_q9_assets scr_q10_hh_area scr_q11_summer_hh scr_q12_poweralt_code scr_q13_vacay_code ///
		scr_q14_dineout scr_q15_income ///
		scr_q16_income_subj scr_econ_status /// 
		pre_q15_a_concern_1 pre_q15_b_concern_2 pre_q15_c_concern_3 pre_q3_sect ///
		pre_q1_gender pre_q2_age pre_q9_class pre_q8_income pre_q10_diffecon pre_q11_a_zaimhelp pre_q11_b_relhelp ///
		pre_q4_changesect pre_q5_diffsect pre_q12_a_marry pre_q12_b_doctor pre_q12_c_neighbor ///
		pre_q12_d_poltalk pre_q12_e_econtalk pre_q12_f_supervisor pre_q12_g_friends ///
		pre_q7_a_friends pre_q7_b_elites pre_q7_c_petition pre_q7_d_protest pre_q13_disagree pre_q6_polparty ///
		pre_q14_a_agegrp pre_q14_b_gender pre_q14_c_confession pre_q14_d_class pre_q14_e_lebanese pre_q14_f_occupation ///
		post_q1_g_learned post_q1_h_empthem post_q1_i_empyou post_q1_j_anxious ///
		post_q2_simconcerns post_q3_surprise_econ post_q4_agreechange post_q5_surprise_sect ///
		post_q7_knowppl post_q8_a_low_sun post_q8_b_low_chr post_q8_c_low_shi post_q8_d_upp_sun post_q8_e_upp_chr ///
		post_q8_f_upp_shi post_q14_domidentity ///
		post_q9_a_lchr_uchr post_q9_b_lsun_usun post_q9_c_lshi_ushi post_q9_d_lshi_lsun post_q9_e_lsun_lchr ///
		post_q9_f_lchr_lshi post_q9_g_ushi_usun post_q9_h_usun_uchr post_q9_i_uchr_ushi ///
		post_q10_a_enemies post_q10_b_worry post_q10_c_unsure ///
		pet_allsign ///
		pgg_rd1 pgg_rd2 ///
		me_beirut me_baalbek me_hasbaya me_hermel me_rashaya me_westbekaa me_zahle ///
		me_aley me_baabda me_chouf me_jbeil me_keserwan me_metn me_bintjbeil ///
		me_marjayoun me_nabatieh me_akkar me_batroun me_becharre me_koura me_minieh ///
		me_tripoli me_zgharta me_jezzine me_saida me_sour ///
		wgt_strat2 wgt_strat3_particip ms_q1_mod_id map_alloc_tot ///
		scr_q1_gender_REC2 scr_q3_marital_REC1 scr_q4_educ_REC1 scr_q6_work_REC1 scr_q9_assets_REC1 ///
		scr_q14_dineout_REC1 scr_q16_income_subj_REC1 ///
		pre_q15_a_concern_1_REC1 pre_q15_b_concern_2_REC1 pre_q15_c_concern_3_REC1 ///
		pre_q3_sect_REC3 pre_q9_class_REC1 pre_q9_class_REC3b ///
		pre_q1_gender_REC2 pre_q8_income_REC1 pre_q10_diffecon_REC1 pre_q11_a_zaimhelp_REC1 pre_q11_b_relhelp_REC1 ///
		pre_q4_changesect_REC1 pre_q5_diffsect_REC1 pre_q12_a_marry_REC1 pre_q12_b_doctor_REC1 pre_q12_c_neighbor_REC1 ///
		pre_q12_d_poltalk_REC1 pre_q12_e_econtalk_REC1 pre_q12_f_supervisor_REC1 pre_q12_g_friends_REC1 pre_q14_f_occupation_REC1 ///
		pre_q7_a_friends_REC1 pre_q7_b_elites_REC1 pre_q7_c_petition_REC1 pre_q7_d_protest_REC1 pre_q13_disagree_REC1 ///
		pre_q14_a_agegrp_REC1 pre_q14_b_gender_REC1 pre_q14_c_confession_REC1 pre_q14_d_class_REC1 pre_q14_e_lebanese_REC1 ///
		pre_q6_polparty_REC3 ///
		post_q1_a_express_REC1 post_q1_b_justified_REC1 post_q1_c_selfish_REC1 post_q1_d_hiding_REC1 post_q1_e_changemind_REC1 ///
		post_q1_f_serious_REC1 post_q1_g_learned_REC1 post_q1_h_empthem_REC1 post_q1_i_empyou_REC1 post_q1_j_anxious_REC1 ///
		post_q2_simconcerns_REC1 post_q3_surprise_econ_REC1 post_q4_agreechange_REC1 post_q5_surprise_sect_REC1 ///
		post_q8_a_low_sun_REC1 post_q8_b_low_chr_REC1 post_q8_c_low_shi_REC1 post_q8_d_upp_sun_REC1 post_q8_e_upp_chr_REC1 ///
		post_q9_a_lchr_uchr_REC1 post_q9_b_lsun_usun_REC1 post_q9_c_lshi_ushi_REC1 post_q9_d_lshi_lsun_REC1 post_q9_e_lsun_lchr_REC1 ///
		post_q9_f_lchr_lshi_REC1 post_q9_g_ushi_usun_REC1 post_q9_h_usun_uchr_REC1 post_q9_i_uchr_ushi_REC1 ///
		post_q10_a_enemies_REC1 post_q10_b_worry_REC1 post_q10_c_unsure_REC1 ///
		post_q7_knowppl_REC1 post_q8_f_upp_shi_REC1 ///
		post_q14_domidentity_REC1b ///
		me_beirut_REC1 me_baalbek_REC1 me_hasbaya_REC1 me_hermel_REC1 me_rashaya_REC1 me_westbekaa_REC1 me_zahle_REC1 me_aley_REC1 ///
		me_baabda_REC1 me_chouf_REC1 me_jbeil_REC1 me_keserwan_REC1 me_metn_REC1 me_bintjbeil_REC1 me_marjayoun_REC1 me_nabatieh_REC1 ///
		me_akkar_REC1 me_batroun_REC1 me_becharre_REC1 me_koura_REC1 me_minieh_REC1 me_tripoli_REC1 me_zgharta_REC1 me_jezzine_REC1 me_saida_REC1 me_sour_REC1 ///
		m_impute _mi_id _mi_miss _mi_m _mi _mj n_gid

	
*******************************************************
*MERGE IN DATA FROM MODERATOR SURVEY
*******************************************************
	
	sort gid
	merge m:1 gid using "$data_orig/ms_q30_REV_final.dta"
	drop _merge
	
	sort gid
	merge m:1 gid using "$data_orig/ms_q36_REV_final.dta"
	drop _merge

			
/*******************************************************
*RENAME WEIGHTS
	wgt1 = 1 (for the sample)
	wgt4 = 'small' strata weight (accounts for uneq prob assignment within blocks and weights sample to 'population' assigned
	wgt6 = 'big' strata weight (weights sample to 'pop' assigned, eq prob assignment within blocks)
*******************************************************/
	
	g wgt1 = 1
	g wgt4 = wgt_strat2
	g wgt6 = wgt_strat3_particip
		
*******************************************************
*SCREENING SURVEY
*******************************************************

	g poor = scr_econ_status==0
	g rich = scr_econ_status==1

	recode scr_q3_marital_REC1 (2=1) (1 4 5=0), g(scr_q3_marital_REC2)

*Education (at least high school, includes technical degree)
	recode scr_q4_educ_REC1 (4/6=0) (7/10=1), g(scr_q4_educ_REC2)	
	
*Moderator indicator
	g mod1 = ms_q1_mod_id==10
	

*******************************************************
*PRE-TREATMENT SURVEY
*******************************************************

*Group treatment indicators
	g group1 = final_assign==1
	g group2 = final_assign==2
	g group3 = final_assign==3
	g group4 = final_assign==4	

*Age
	xtile pre_q2_age_REC2= pre_q2_age, nquant(2)
	recode pre_q2_age_REC2 (1=0) (2=1)
	
	g pre_q3_christian = scr_q8_sect==1
	g pre_q3_sunni = scr_q8_sect==2
	g pre_q3_shia = scr_q8_sect==3	
	
	lab def confess 1 "Christian" 2 "Sunni" 3 "Shia", modify	
	lab val pre_q3_sect_REC3 confess

	
*Generate class + sect indicator	
	g class_confess = 1 if scr_econ_status==0 & pre_q3_sect_REC3==1
		replace class_confess = 2 if scr_econ_status==0 & pre_q3_sect_REC3==2
		replace class_confess = 3 if scr_econ_status==0 & pre_q3_sect_REC3==3
		replace class_confess = 4 if scr_econ_status==1 & pre_q3_sect_REC3==1
		replace class_confess = 5 if scr_econ_status==1 & pre_q3_sect_REC3==2
		replace class_confess = 6 if scr_econ_status==1 & pre_q3_sect_REC3==3

	lab def class_confess 1 "Poor Christian" 2 "Poor Sunni" 3 "Poor Shia" 4 "Rich Christian" 5 "Rich Sunni" 6 "Rich Shia", modify	
	lab val class_confess class_confess
	
	g poor_chr = class_confess==1
	g poor_sun = class_confess==2
	g poor_shi = class_confess==3
	g rich_chr = class_confess==4
	g rich_sun = class_confess==5
	g rich_shi = class_confess==6
	

*Politically engaged	
	local act pre_q7_a_friends_REC1 pre_q7_b_elites_REC1 pre_q7_c_petition_REC1 pre_q7_d_protest_REC1 

	foreach item in act {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	


*Economic status	
	local econ_all scr_q9_assets_REC1 scr_q10_hh_area scr_q11_summer_hh scr_q12_poweralt_code scr_q13_vacay_code scr_q14_dineout_REC1 scr_q15_income scr_q16_income_subj_REC1 pre_q8_income_REC1 pre_q9_class_REC3b 


	foreach item in econ_all {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	

	
*Network heterogeneity	
	local soc_hom pre_q10_diffecon_REC1 pre_q5_diffsect_REC1
	
	foreach item in soc_hom {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	

	
	lab def class_homog1 1 "Almost all from diff class" 2 "Most from diff class" 3 "Some from diff class" 4 "A few from diff class" 5 "Almost none from diff class", modify	
	lab val pre_q10_diffecon_REC1 class_homog1 

	lab def sect_homog1 1 "Almost all from diff sect" 2 "Most from diff sect" 3 "Some from diff sect" 4 "A few from diff sect" 5 "Almost none from diff sect", modify	
	lab val pre_q5_diffsect_REC1 sect_homog1

	
*Connected 
	local connect pre_q11_a_zaimhelp_REC1 pre_q11_b_relhelp_REC1

	foreach item in connect {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
	}
}

	
*Prejudice	
	local prej pre_q12_a_marry_REC1 pre_q12_b_doctor_REC1 pre_q12_c_neighbor_REC1 pre_q12_d_poltalk_REC1 pre_q12_e_econtalk_REC1 pre_q12_f_supervisor_REC1 pre_q12_g_friends_REC1 
	
	foreach item in prej {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	
	

*Sectarian identity	
	recode pre_q6_polparty_REC3 (1=3) (2=2) (3=1), g(pre_q6_polparty_REC3b)

	recode pre_q14_c_confession_REC1 (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), g(pre_q14_c_confession_REC1b)
	
	local sect_id pre_q4_changesect_REC1 pre_q6_polparty_REC3b pre_q14_c_confession_REC1b	
	
	foreach item in sect_id {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	
	
	
*Q14 ID
*Confessional identity ranked top 	
	recode pre_q14_d_class_REC1 (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), g(pre_q14_d_class_REC1b)

	recode pre_q14_f_occupation_REC1 (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), g(pre_q14_f_occupation_REC1b)
	
*Q15 PRIORITIES 
	recode pre_q15_a_concern_1_REC1 (1=1) (2=2) (18=3) (22=4) (27=5) (3/12=6) (13/17 19/21=7) (23/26=8) (28/30=9), g(pre_q15_concern_1_main)
		lab def pre_q15_concern_1_main 1 "Prices" 2 "Unemployment" 3 "Sectarianism" 4 "Civil War" 5 "Terrorism" 6 "Other Econ" 7 "Other Social" 8 "Other Security" 9 "Other", modify
		lab val pre_q15_concern_1_main pre_q15_concern_1_main

	recode pre_q15_b_concern_2_REC1 (1=1) (2=2) (6=3) (12=4) (14=5) (17=6) (18=7) (20=8) (22=9) (27=10) (3/5 7/11=11) (13 15/16 19 21=12) (23/26=13) (28/30=14), g(pre_q15_concern_2_main)

*Economic concerns	
	g concern_prices_all = pre_q15_a_concern_1_REC1==1 |  pre_q15_b_concern_2_REC1==1 | pre_q15_c_concern_3_REC1 == 1
	g concern_unemp_all = pre_q15_a_concern_1_REC1==2 |  pre_q15_b_concern_2_REC1==2 | pre_q15_c_concern_3_REC1 == 2
	g concern_deficit_all = pre_q15_a_concern_1_REC1==3 |  pre_q15_b_concern_2_REC1==3 | pre_q15_c_concern_3_REC1 == 3
	g concern_oil_all = pre_q15_a_concern_1_REC1==4 |  pre_q15_b_concern_2_REC1==4 | pre_q15_c_concern_3_REC1 == 4
	g concern_manu_all = pre_q15_a_concern_1_REC1==5 |  pre_q15_b_concern_2_REC1==5 | pre_q15_c_concern_3_REC1 == 5
	g concern_costs_all = pre_q15_a_concern_1_REC1==6 |  pre_q15_b_concern_2_REC1==6 | pre_q15_c_concern_3_REC1 == 6
	g concern_electric_all = pre_q15_a_concern_1_REC1==7 |  pre_q15_b_concern_2_REC1==7 | pre_q15_c_concern_3_REC1 == 7
	g concern_locdev_all = pre_q15_a_concern_1_REC1==8 |  pre_q15_b_concern_2_REC1==8 | pre_q15_c_concern_3_REC1 == 8
	g concern_transport_all = pre_q15_a_concern_1_REC1==9 |  pre_q15_b_concern_2_REC1==9 | pre_q15_c_concern_3_REC1 == 9
	g concern_ineq_all = pre_q15_a_concern_1_REC1==10 |  pre_q15_b_concern_2_REC1==10 | pre_q15_c_concern_3_REC1 == 10
	g concern_poverty_all = pre_q15_a_concern_1_REC1==12 |  pre_q15_b_concern_2_REC1==12 | pre_q15_c_concern_3_REC1 == 12
	g concern_food_all = pre_q15_a_concern_1_REC1==13 |  pre_q15_b_concern_2_REC1==13 | pre_q15_c_concern_3_REC1 == 13
	
*Political concerns	
	g concern_radic_all = pre_q15_a_concern_1_REC1==14 |  pre_q15_b_concern_2_REC1==14 | pre_q15_c_concern_3_REC1 == 14
	g concern_judic_all = pre_q15_a_concern_1_REC1==15 |  pre_q15_b_concern_2_REC1==15 | pre_q15_c_concern_3_REC1 == 15
	g concern_elect_all = pre_q15_a_concern_1_REC1==16 |  pre_q15_b_concern_2_REC1==16 | pre_q15_c_concern_3_REC1 == 16
	g concern_corrupt_all = pre_q15_a_concern_1_REC1==17 |  pre_q15_b_concern_2_REC1==17 | pre_q15_c_concern_3_REC1 == 17
	g concern_sect_all = pre_q15_a_concern_1_REC1==18 |  pre_q15_b_concern_2_REC1==18 | pre_q15_c_concern_3_REC1 == 18
	g concern_crime_all = pre_q15_a_concern_1_REC1==19 |  pre_q15_b_concern_2_REC1==19 | pre_q15_c_concern_3_REC1 == 19
	g concern_garbage_all = pre_q15_a_concern_1_REC1==20 |  pre_q15_b_concern_2_REC1==20 | pre_q15_c_concern_3_REC1 == 20
	g concern_war_all = pre_q15_a_concern_1_REC1==22 |  pre_q15_b_concern_2_REC1==22 | pre_q15_c_concern_3_REC1 == 22
	g concern_israel_all = pre_q15_a_concern_1_REC1==23 |  pre_q15_b_concern_2_REC1==23 | pre_q15_c_concern_3_REC1 == 23
	g concern_instab_all = pre_q15_a_concern_1_REC1==24 |  pre_q15_b_concern_2_REC1==24 | pre_q15_c_concern_3_REC1 == 24
	g concern_weapons_all = pre_q15_a_concern_1_REC1==25 |  pre_q15_b_concern_2_REC1==25 | pre_q15_c_concern_3_REC1 == 25
	g concern_groups_all = pre_q15_a_concern_1_REC1==26 |  pre_q15_b_concern_2_REC1==26 | pre_q15_c_concern_3_REC1 == 26
	g concern_terror_all = pre_q15_a_concern_1_REC1==27 |  pre_q15_b_concern_2_REC1==27 | pre_q15_c_concern_3_REC1 == 27
	
	
	foreach var in concern_prices_all concern_unemp_all {
		mi xeq: egen mean_`var' = mean(`var'), by(class_confess)
	}	
		
	mi xeq: egen tag_class_confess = tag(class_confess)

	recode pre_q5_diffsect_REC1 (1/2=1) (3/5=0), g(pre_q5_mostly_het_sect)
	recode pre_q10_diffecon_REC1 (1/2=1) (3/5=0), g(pre_q10_mostly_het_class)

*******************************************************
*POST TREATMENT
*******************************************************

*Empathy index
	foreach var of varlist post_q1_h_empthem post_q1_i_empyou {
		recode `var'_REC1 (1=4) (2=3) (3=2) (4=1), g(`var'_REC1b)
		recode `var'_REC1b (3/4=1) (1/2=0), g(`var'_REC2b)
	}
	
	local y_empathy post_q1_h_empthem_REC1b post_q1_i_empyou_REC1b

	foreach item in y_empathy {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	

*Agreement		
	foreach var of varlist post_q2_simconcerns post_q4_agreechange {
		recode `var'_REC1 (4=1) (3=2) (2=3) (1=4), g(`var'_REC1b)
	}	

	local y_agree post_q2_simconcerns_REC1b post_q4_agreechange_REC1b
	
	foreach item in y_agree {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	
			
*Learning
	foreach var of varlist post_q3_surprise_econ post_q5_surprise_sect {
		recode `var'_REC1 (1=4) (2=3) (3=2) (4=1), g(`var'_REC1b)
	}

	
	foreach var of varlist post_q1_g_learned  {
		recode `var'_REC1 (1=4) (2=3) (3=2) (4=1), g(`var'_REC1b)
	}

	local y_learned post_q1_g_learned_REC1b post_q3_surprise_econ_REC1b post_q5_surprise_sect_REC1b
	
	foreach item in y_learned  {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	
	
	
*Learn about shared prefs index	
	local y_learn_shared post_q1_g_learned_REC1b post_q3_surprise_econ_REC1b post_q5_surprise_sect_REC1b post_q2_simconcerns_REC1b post_q4_agreechange_REC1b 	
	
	foreach item in y_learn_shared {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
	}
	}
	
*Social pressure and cross pressure variables	
	foreach var of varlist post_q10_a_enemies post_q10_b_worry post_q10_c_unsure {
		recode `var'_REC1 (1=4) (2=3) (3=2) (4=1), g(`var'_REC1b)
	}

	local y_press post_q10_a_enemies_REC1b post_q10_b_worry_REC1b
	
	foreach item in y_press {
		foreach weight in wgt1 wgt4 wgt6 {
			mi xeq: make_index `item'_`weight' `weight' ``item''
		}
	}	

	
*Social identity/self-categorization		
	g q8_id_same_sect_same_class = .		
		replace q8_id_same_sect_same_class = post_q8_a_low_sun_REC1 if pre_q3_sunni==1 & poor==1
		replace q8_id_same_sect_same_class = post_q8_b_low_chr_REC1 if pre_q3_christian==1 & poor==1
		replace q8_id_same_sect_same_class = post_q8_c_low_shi_REC1 if pre_q3_shia==1 & poor==1
		replace q8_id_same_sect_same_class = post_q8_d_upp_sun_REC1 if pre_q3_sunni==1 & rich==1
		replace q8_id_same_sect_same_class = post_q8_e_upp_chr_REC1 if pre_q3_christian==1 & rich==1
		replace q8_id_same_sect_same_class = post_q8_f_upp_shi_REC1 if pre_q3_shia==1 & rich==1
		
	g q8_id_same_sect_diff_class = .		
		replace q8_id_same_sect_diff_class = post_q8_a_low_sun_REC1 if pre_q3_sunni==1 & rich==1
		replace q8_id_same_sect_diff_class = post_q8_b_low_chr_REC1 if pre_q3_christian==1 & rich==1
		replace q8_id_same_sect_diff_class = post_q8_c_low_shi_REC1 if pre_q3_shia==1 & rich==1
		replace q8_id_same_sect_diff_class = post_q8_d_upp_sun_REC1 if pre_q3_sunni==1 & poor==1
		replace q8_id_same_sect_diff_class = post_q8_e_upp_chr_REC1 if pre_q3_christian==1 & poor==1
		replace q8_id_same_sect_diff_class = post_q8_f_upp_shi_REC1 if pre_q3_shia==1 & poor==1
		
	g q8_id_diff_sect_same_class = .		
		replace q8_id_diff_sect_same_class = (post_q8_b_low_chr_REC1 + post_q8_c_low_shi_REC1)/2 if pre_q3_sunni==1 & poor==1
		replace q8_id_diff_sect_same_class = (post_q8_a_low_sun_REC1 + post_q8_c_low_shi_REC1)/2 if pre_q3_christian==1 & poor==1
		replace q8_id_diff_sect_same_class = (post_q8_b_low_chr_REC1 + post_q8_a_low_sun_REC1)/2 if pre_q3_shia==1 & poor==1
		replace q8_id_diff_sect_same_class = (post_q8_e_upp_chr_REC1 + post_q8_f_upp_shi_REC1)/2 if pre_q3_sunni==1 & rich==1
		replace q8_id_diff_sect_same_class = (post_q8_d_upp_sun_REC1 + post_q8_f_upp_shi_REC1)/2 if pre_q3_christian==1 & rich==1
		replace q8_id_diff_sect_same_class = (post_q8_d_upp_sun_REC1 + post_q8_e_upp_chr_REC1)/2 if pre_q3_shia==1 & rich==1
		
	g q8_id_diff_sect_diff_class = .		
		replace q8_id_diff_sect_diff_class = (post_q8_e_upp_chr_REC1 + post_q8_f_upp_shi_REC1)/2 if pre_q3_sunni==1 & poor==1
		replace q8_id_diff_sect_diff_class = (post_q8_d_upp_sun_REC1 + post_q8_f_upp_shi_REC1)/2 if pre_q3_christian==1 & poor==1
		replace q8_id_diff_sect_diff_class = (post_q8_e_upp_chr_REC1 + post_q8_d_upp_sun_REC1)/2 if pre_q3_shia==1 & poor==1
		replace q8_id_diff_sect_diff_class = (post_q8_c_low_shi_REC1 + post_q8_b_low_chr_REC1)/2 if pre_q3_sunni==1 & rich==1
		replace q8_id_diff_sect_diff_class = (post_q8_a_low_sun_REC1 + post_q8_c_low_shi_REC1)/2 if pre_q3_christian==1 & rich==1
		replace q8_id_diff_sect_diff_class = (post_q8_b_low_chr_REC1 + post_q8_a_low_sun_REC1)/2 if pre_q3_shia==1 & rich==1
		
*GROUP DISTANCE VARS
*Shared preferences with co-ethnics (distance between poor and rich of same sect)
	g q9_dist_same_sect_diff_class = .
		replace q9_dist_same_sect_diff_class = post_q9_a_lchr_uchr_REC1 if pre_q3_christian==1
		replace q9_dist_same_sect_diff_class = post_q9_b_lsun_usun_REC1 if pre_q3_sunni==1
		replace q9_dist_same_sect_diff_class = post_q9_c_lshi_ushi_REC1 if pre_q3_shia==1	
		
*Distance between rich of different sects
	gen post_q9_diffsect_rich_chr = post_q9_g_ushi_usun_REC1 if pre_q3_christian==1
	gen post_q9_diffsect_rich_sun = post_q9_i_uchr_ushi_REC1 if pre_q3_sunni==1
	gen post_q9_diffsect_rich_shi = post_q9_h_usun_uchr_REC1 if pre_q3_shia==1
	
		foreach var of varlist post_q9_diffsect_rich_chr post_q9_diffsect_rich_sun post_q9_diffsect_rich_shi {
					recode `var' (.=0), g(`var'_t)
					}

	gen post_q9_diffsect_rich = post_q9_diffsect_rich_chr_t + post_q9_diffsect_rich_sun_t + post_q9_diffsect_rich_shi_t
		recode post_q9_diffsect_rich (0=.) 
		lab var post_q9_diffsect_rich "Distance between rich of other sects"

*Distance between poor of different sects
	gen post_q9_diffsect_poor_chr = post_q9_d_lshi_lsun_REC1 if pre_q3_christian==1
	gen post_q9_diffsect_poor_sun = post_q9_f_lchr_lshi_REC1 if pre_q3_sunni==1
	gen post_q9_diffsect_poor_shi = post_q9_e_lsun_lchr_REC1 if pre_q3_shia==1
	
			foreach var of varlist post_q9_diffsect_poor_chr post_q9_diffsect_poor_sun post_q9_diffsect_poor_shi {
					recode `var' (.=0), g(`var'_t)
					}

	gen post_q9_diffsect_poor = post_q9_diffsect_poor_chr_t + post_q9_diffsect_poor_sun_t + post_q9_diffsect_poor_shi_t
			
	recode post_q9_diffsect_poor (0=.) 
			
	lab var post_q9_diffsect_poor "Distance between poor of other sects"
			
		
*******************************************************
*PUBLIC GOODS GAME
*******************************************************

	g pgg_diff = pgg_rd2 - pgg_rd1 

	mi xeq: bysort gid: egen mean_pgg_rd1_g1 = mean(pgg_rd1) if final_assign==1
	mi xeq: bysort gid: egen mean_pgg_rd1_g2 = mean(pgg_rd1) if final_assign==2
	mi xeq: bysort gid: egen mean_pgg_rd1_g3 = mean(pgg_rd1) if final_assign==3
	mi xeq: bysort gid: egen mean_pgg_rd1_g4 = mean(pgg_rd1) if final_assign==4

	mi xeq: bysort gid: egen mean_pgg_rd2_g1 = mean(pgg_rd2) if final_assign==1
	mi xeq: bysort gid: egen mean_pgg_rd2_g2 = mean(pgg_rd2) if final_assign==2
	mi xeq: bysort gid: egen mean_pgg_rd2_g3 = mean(pgg_rd2) if final_assign==3
	mi xeq: bysort gid: egen mean_pgg_rd2_g4 = mean(pgg_rd2) if final_assign==4

	mi xeq: bysort gid: egen mean_pgg_diff_g1 = mean(pgg_diff) if final_assign==1
	mi xeq: bysort gid: egen mean_pgg_diff_g2 = mean(pgg_diff) if final_assign==2
	mi xeq: bysort gid: egen mean_pgg_diff_g3 = mean(pgg_diff) if final_assign==3
	mi xeq: bysort gid: egen mean_pgg_diff_g4 = mean(pgg_diff) if final_assign==4

	
*******************************************************
*MAP VARIABLES
*******************************************************
	sort pid m_impute

* recode me_sour_REC1 because of one observation not imputed
	recode me_sour_REC1 (.=0) if m_impute!=0

*ALLOCATIONS BY DOMINANT SECT IN DISTRICT (Sunni, Shia, & Christian or Christian/Druze districts only)
*total to sunni districts
	gen me_sunni = me_westbekaa_REC1 + me_akkar_REC1 + me_minieh_REC1 + me_tripoli_REC1 + me_saida_REC1
		lab var me_sunni "Total allocated to Sunni districts"

* total to shia districts
	gen me_shia = me_baalbek_REC1 + me_hermel_REC1 + me_bintjbeil_REC1 + me_marjayoun_REC1 + me_nabatieh_REC1 + me_sour_REC1
		lab var me_shia "Total allocated to Shia districts"

* total to christian and christian/druze districts
	gen me_chr = me_hasbaya_REC1 + me_chouf_REC1 + me_zahle_REC1 + me_baabda_REC1 + me_jbeil_REC1 + me_keserwan_REC1 + me_metn_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_koura_REC1 + me_zgharta_REC1 + me_jezzine_REC1
		lab var me_chr "Total allocated to Christian districts (incl. Christian/Druze districts)"
	
	
* ALLOCATIONS BY DISTRICT DEV (1/2 = rich/developed ; 3 = middle dev. ; 4/5 = poor/underdev), includes me_beirut_REC1 as a rich district
* total to rich districts
	gen me_rich = me_beirut_REC1 + me_westbekaa_REC1 + me_zahle_REC1 + me_baabda_REC1 + me_jbeil_REC1 + me_keserwan_REC1 + me_metn_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_koura_REC1
		lab var me_rich "Total allocated to rich/developed districts"

* total to rich districts without Beirut
	gen me_rich_nobeirut = me_westbekaa_REC1 + me_zahle_REC1 + me_baabda_REC1 + me_jbeil_REC1 + me_keserwan_REC1 + me_metn_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_koura_REC1
		lab var me_rich_nobeirut "Total allocated to rich/developed districts, no Beirut"

* total to mid districts
	gen me_mid = me_aley_REC1 + me_chouf_REC1 + me_nabatieh_REC1 + me_tripoli_REC1 + me_zgharta_REC1 + me_jezzine_REC1 + me_saida_REC1 + me_sour_REC1
		lab var me_mid "Total allocated to mid/developed districts"

* total to poor districts
	gen me_poor = me_baalbek_REC1 + me_hasbaya_REC1 + me_hermel_REC1 + me_rashaya_REC1 + me_bintjbeil_REC1 + me_marjayoun_REC1 + me_akkar_REC1 + me_minieh_REC1
		lab var me_poor "Total allocated to poor/undeveloped districts"

	
* ALLOCATION TO COSECT DISTRICTS
	gen me_map_tot = me_akkar_REC1 + me_aley_REC1 + me_baabda_REC1 + me_baalbek_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_beirut_REC1 + me_bintjbeil_REC1 + me_chouf_REC1 + me_hasbaya_REC1 + me_hermel_REC1 + me_jbeil_REC1 + me_jezzine_REC1 + me_keserwan_REC1 + me_koura_REC1 + me_marjayoun_REC1 + me_metn_REC1 + me_minieh_REC1 + me_nabatieh_REC1 + me_rashaya_REC1 + me_saida_REC1 + me_sour_REC1 + me_tripoli_REC1 + me_westbekaa_REC1 + me_zahle_REC1 + me_zgharta_REC1	
		lab var me_map_tot "Check for 100% allocation in dialogues map exercise"

* total allocated to Sunni districts if Sunni
	gen me_same_sunni = me_sunni if pre_q3_sunni==1
			recode me_same_sunni (.=0) if me_map_tot!=.			

* total allocated to shia districts if shia
	gen me_same_shia = me_shia if pre_q3_shia==1
			recode me_same_shia (.=0) if me_map_tot!=.			
			
* total allocated to christian districts if christian
	gen me_same_chr = me_chr if pre_q3_christian==1
			recode me_same_chr (.=0) if me_map_tot!=.			
			
* overall total allocated to co-sectarian districts
	gen me_same_sect = me_same_sunni + me_same_shia + me_same_chr
	lab var me_same_sect "Total allocated to co-sectarian districts"
	
	
*ALLOCATIONS TO NONCOSECT DISTRICTS	
* total to non-cosectarian districts if sunni
	gen me_other_sunni = (me_baalbek_REC1 + me_hermel_REC1 + me_bintjbeil_REC1 + me_marjayoun_REC1 + me_nabatieh_REC1 + me_sour_REC1 + me_hasbaya_REC1 + me_chouf_REC1 + me_zahle_REC1 + me_baabda_REC1 + me_jbeil_REC1 + me_keserwan_REC1 + me_metn_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_koura_REC1 + me_zgharta_REC1 + me_jezzine_REC1 + me_rashaya_REC1 + me_aley_REC1) if pre_q3_sunni==1
			recode me_other_sunni (.=0) if me_map_tot!=.					
			lab var me_other_sunni "Total allocated to non-cosectarian districts if Sunni"

* total to non-cosectarian districts if shia
	gen me_other_shia = (me_westbekaa_REC1 + me_akkar_REC1 + me_minieh_REC1 + me_tripoli_REC1 + me_saida_REC1 + me_hasbaya_REC1 + me_chouf_REC1 + me_zahle_REC1 + me_baabda_REC1 + me_jbeil_REC1 + me_keserwan_REC1 + me_metn_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_koura_REC1 + me_zgharta_REC1 + me_jezzine_REC1 + me_rashaya_REC1 + me_aley_REC1) if pre_q3_shia==1
			recode me_other_shia (.=0) if me_map_tot!=.					
			lab var me_other_shia "Total allocated to non-cosectarian districts if Shia"
		
* total to non-cosectarian districts if christian
	gen me_other_chr = (me_westbekaa_REC1 + me_akkar_REC1 + me_minieh_REC1 + me_tripoli_REC1 + me_saida_REC1 + me_baalbek_REC1 + me_hermel_REC1 + me_bintjbeil_REC1 + me_marjayoun_REC1 + me_nabatieh_REC1 + me_sour_REC1 + me_rashaya_REC1 + me_aley_REC1) if pre_q3_christian==1
			recode me_other_chr (.=0) if me_map_tot!=.					
			lab var me_other_chr "Total allocated to non-cosectarian districts if Christian"
		
* overall total allocated to non-cosectarian districts
	gen me_other_sect = me_other_sunni + me_other_shia + me_other_chr
	lab var me_other_sect "Total allocated to non-cosectarian districts"
	
*ALLOCATIONS TO POOR COSECT DISTRICTS	
		* total to poor, Sunni areas if sunni
			gen me_same_poor_sunni = (me_akkar_REC1 + me_minieh_REC1) if pre_q3_sunni==1
			recode me_same_poor_sunni (.=0) if me_map_tot!=. 
			lab var me_same_poor_sunni "Total to poor Sunni areas if Sunni"
				
		* total to poor, Shia areas if shia
			gen me_same_poor_shia = (me_baalbek_REC1 + me_hermel_REC1 + me_bintjbeil_REC1 + me_marjayoun_REC1) if pre_q3_shia==1
			recode me_same_poor_shia (.=0) if me_map_tot!=. 
			lab var me_same_poor_shia "Total to poor Shia areas if Shia"
								
		* total to poor, Christian and Christian/Druze areas if christian
			gen me_same_poor_chr = me_hasbaya_REC1 if pre_q3_christian==1			
			recode me_same_poor_chr (.=0) if me_map_tot!=. 
			lab var me_same_poor_chr "Total to poor Christian & Chr/Druze areas if Christian"

* overall total to poor co-sectarian districts
	gen me_same_poor = me_same_poor_sunni + me_same_poor_shia + me_same_poor_chr
	lab var me_same_poor "Total allocated to poor co-sectarian districts"
	
	
*ALLOCATIONS TO POOR NONCOSECT DISTRICTS	
		* total to non-sunni poor districts if sunni
			gen me_other_poor_sunni = (me_hasbaya_REC1 + me_baalbek_REC1 + me_hermel_REC1 + me_bintjbeil_REC1 + me_marjayoun_REC1 + me_rashaya_REC1) if pre_q3_sunni==1
			recode me_other_poor_sunni (.=0) if me_map_tot!=. 
			lab var me_other_poor_sunni "Total to poor non-Sunni areas if Sunni"
		
		* total to non-shia poor districts if shia
			gen me_other_poor_shia = (me_akkar_REC1 + me_minieh_REC1 + me_hasbaya_REC1 + me_rashaya_REC1) if pre_q3_shia==1
			recode me_other_poor_shia (.=0) if me_map_tot!=. 
			lab var me_other_poor_shia "Total to poor non-Shia areas if Shia"
								
		* total to non-christian poor districts if christian
			gen me_other_poor_chr = (me_akkar_REC1 + me_minieh_REC1 + me_baalbek_REC1 + me_hermel_REC1 + me_bintjbeil_REC1 + me_marjayoun_REC1 + me_rashaya_REC1) if pre_q3_christian==1			
			recode me_other_poor_chr (.=0) if me_map_tot!=. 
			lab var me_other_poor_chr "Total to poor non-Christian & Chr/Druze areas if Christian"

* overall total to poor nonco-sectarian districts
	gen me_other_poor = me_other_poor_sunni + me_other_poor_shia + me_other_poor_chr
	lab var me_other_poor "Total allocated to poor non-cosectarian districts"

*ALLOCATIONS TO MID COSECT DISTRICTS	
		* total to middle, Sunni areas if sunni
			gen me_same_mid_sunni = (me_tripoli_REC1 + me_saida_REC1) if pre_q3_sunni==1
			recode me_same_mid_sunni (.=0) if me_map_tot!=. 
			lab var me_same_mid_sunni "Total to middle Sunni areas if Sunni"

		* total to middle, Shia areas if shia
			gen me_same_mid_shia = (me_nabatieh_REC1 + me_sour_REC1) if pre_q3_shia==1
			recode me_same_mid_shia (.=0) if me_map_tot!=. 
			lab var me_same_mid_shia "Total to middle Shia areas if Shia"
								
		* total to middle, Christian and Christian/Druze areas if christian
			gen me_same_mid_chr = (me_chouf_REC1 + me_zgharta_REC1 + me_jezzine_REC1) if pre_q3_christian==1			
			recode me_same_mid_chr (.=0) if me_map_tot!=. 
			lab var me_same_mid_chr "Total to middle Christian & Chr/Druze areas if Christian"

* overall total to middle co-sectarian districts
	gen me_same_mid = me_same_mid_sunni + me_same_mid_shia + me_same_mid_chr
	lab var me_same_mid "Total allocated to middle co-sectarian districts"
		
*ALLOCATIONS TO MID NONCOSECT DISTRICTS		
		* total to non-sunni middle districts if sunni
			gen me_other_mid_sunni = (me_chouf_REC1 + me_zgharta_REC1 + me_jezzine_REC1 + me_nabatieh_REC1 + me_sour_REC1 + me_aley_REC1) if pre_q3_sunni==1
			recode me_other_mid_sunni (.=0) if me_map_tot!=. 
			lab var me_other_mid_sunni "Total to middle non-Sunni areas if Sunni"
		
		* total to non-shia middle districts if shia
			gen me_other_mid_shia = (me_chouf_REC1 + me_zgharta_REC1 + me_jezzine_REC1 + me_tripoli_REC1 + me_saida_REC1 + me_aley_REC1) if pre_q3_shia==1
			recode me_other_mid_shia (.=0) if me_map_tot!=. 
			lab var me_other_mid_shia "Total to middle non-Shia areas if Shia"
								
		* total to non-christian middle districts if christian
			gen me_other_mid_chr = (me_nabatieh_REC1 + me_sour_REC1 + me_tripoli_REC1 + me_saida_REC1 + me_aley_REC1) if pre_q3_christian==1			
			recode me_other_mid_chr (.=0) if me_map_tot!=. 
			lab var me_other_mid_chr "Total to middle non-Christian & Chr/Druze areas if Christian"

* overall total to middle nonco-sectarian districts
	gen me_other_mid = me_other_mid_sunni + me_other_mid_shia + me_other_mid_chr
	lab var me_other_mid "Total allocated to middle non-cosectarian districts"
	
*ALLOCATIONS TO RICH COSECT DISTRICTS	
		* total to rich, Sunni areas if sunni
			gen me_same_rich_sunni = me_westbekaa_REC1 if pre_q3_sunni==1
			recode me_same_rich_sunni (.=0) if me_map_tot!=. 
			lab var me_same_rich_sunni "Total to rich Sunni areas if Sunni"
		
		* total to rich, Shia areas if shia
			gen me_same_rich_shia = 0 if pre_q3_shia==1
			recode me_same_rich_shia (.=0) if me_map_tot!=. 
			lab var me_same_rich_shia "Total to rich Shia areas if Shia"
								
		* total to rich, Christian and Christian/Druze areas if christian
			gen me_same_rich_chr = (me_zahle_REC1 + me_baabda_REC1 + me_jbeil_REC1 + me_keserwan_REC1 + me_metn_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_koura_REC1) if pre_q3_christian==1			
			recode me_same_rich_chr (.=0) if me_map_tot!=. 
			lab var me_same_rich_chr "Total to rich Christian & Chr/Druze areas if Christian"

* overall total to rich co-sectarian districts
	gen me_same_rich = me_same_rich_sunni + me_same_rich_shia + me_same_rich_chr
	lab var me_same_rich "Total allocated to rich co-sectarian districts"
		
*ALLOCATIONS TO RICH NON-COSECT DISTRICTS		
		* total to non-sunni rich districts if sunni
			gen me_other_rich_sunni = (me_zahle_REC1 + me_baabda_REC1 + me_jbeil_REC1 + me_keserwan_REC1 + me_metn_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_koura_REC1) if pre_q3_sunni==1
			recode me_other_rich_sunni (.=0) if me_map_tot!=. 
			lab var me_other_rich_sunni "Total to rich non-Sunni areas if Sunni"
		
		* total to non-shia rich districts if shia
			gen me_other_rich_shia = (me_zahle_REC1 + me_baabda_REC1 + me_jbeil_REC1 + me_keserwan_REC1 + me_metn_REC1 + me_batroun_REC1 + me_becharre_REC1 + me_koura_REC1) if pre_q3_shia==1
			recode me_other_rich_shia (.=0) if me_map_tot!=. 
			lab var me_other_rich_shia "Total to rich non-Shia areas if Shia"
								
		* total to non-christian rich districts if christian
			gen me_other_rich_chr = me_westbekaa_REC1 if pre_q3_christian==1			
			recode me_other_rich_chr (.=0) if me_map_tot!=. 
			lab var me_other_rich_chr "Total to rich non-Christian & Chr/Druze areas if Christian"

* overall total to rich nonco-sectarian districts
	gen me_other_rich = me_other_rich_sunni + me_other_rich_shia + me_other_rich_chr
	lab var me_other_rich "Total allocated to rich non-cosectarian districts"


*******************************************************
*MORE MISC VARS
*******************************************************

	recode pre_q9_class_REC1 (5=1) (4=2) (3=3) (2=4) (1=5), g(pre_q9_class_REC1b)

	recode scr_q6_work_REC1 (2/3=1) (1 4 = 0), g(employed)


*Lebanese ID
	recode pre_q14_e_lebanese_REC1 (7=1) (6=2) (5=3) (4=4) (3=5) (2=6) (1=7), g(pre_q14_leb_REC1b)


*Social network heterogeneity
	g het_netw = 4 if pre_q5_mostly_het_sect==1 & pre_q10_mostly_het_class==1
		replace het_netw = 3 if pre_q5_mostly_het_sect==0 & pre_q10_mostly_het_class==1
		replace het_netw = 2 if pre_q5_mostly_het_sect==1 & pre_q10_mostly_het_class==0
		replace het_netw = 1 if pre_q5_mostly_het_sect==0 & pre_q10_mostly_het_class==0
	
	lab def het_netw 1 "Same sect and class network" 2 "Mixed-sect, same-class network" 3 "Same-sect, mixed-class network" 4 "Mixed sect and class network" , modify
		lab val het_netw het_netw
	
	g netw_type_het = het_netw==4
	g netw_type_mixed = het_netw==2 | het_netw==3
	g netw_type_hom = het_netw==1

*Tag by imputation and gid	
	egen tag_gid = tag(m_impute gid)
	
	
*Redo group ID numbers for graphing (gid same sect 1-60, gid mixed sect 70-130)	
	g order_in_gid=abs(400-gid) if final_assign==4
		replace order_in_gid=abs(300-gid) if final_assign==3
		replace order_in_gid=abs(200-gid) if final_assign==2
		replace order_in_gid=abs(100-gid) if final_assign==1
		
						
/*******************************************************
LABEL VARIABLES
*******************************************************/
				
lab var pre_q1_gender_REC2 "Gender"
lab var pre_q2_age "Age"
lab var scr_q3_marital_REC2 "Marital status"
lab var scr_q4_educ_REC2 "Education"
lab var pre_q3_christian "Christian"
lab var pre_q3_sunni "Sunni"
lab var pre_q3_shia "Shia"
lab var index_econ_all_wgt4 "Economic wealth index"
lab var scr_q6_work_REC1 "Work status"
lab var index_prej_wgt4 "Prejudice index"
lab var index_act_wgt4 "Political action index"
lab var index_soc_hom_wgt4 "Social homogeneity index"
lab var pre_q13_disagree_REC1 "How often do you discuss when disagree"
lab var index_sect_id_wgt4 "Sectarian identity index"
lab var pre_q14_d_class_REC1b "Economic identity"
lab var pre_q14_leb_REC1b "Lebanese identity"
lab var mod1 "Moderator 1 (of 2)"
lab var n_gid "Groups with six participants"
lab var post_q7_knowppl_REC1 "Knew people in group"
lab var scr_q9_assets_REC1 "Assets (screening)"
lab var scr_q10_hh_area "HH area (screening)"
lab var scr_q11_summer_hh "Summer house (screening)"
lab var scr_q12_poweralt_code "Electricity (screening)"
lab var scr_q13_vacay_code "Vacation (screening)"
lab var scr_q14_dineout_REC1 "Dineout (screening)"
lab var scr_q15_income "Household income (screening)"
lab var scr_q16_income_subj_REC1 "Income subjective (screening)"
lab var pre_q8_income_REC1 "Household income (pre-treatment)"
lab var pre_q9_class_REC3b "Self-identified class (pre-treatment)"
lab var pre_q12_a_marry_REC1 "Marrying someone from a diff confession"
lab var pre_q12_b_doctor_REC1 "Diff confession as physician"
lab var pre_q12_c_neighbor_REC1 "Diff confession as neighbor"
lab var pre_q12_d_poltalk_REC1 "Discussing politics with diff confession"
lab var pre_q12_e_econtalk_REC1 "Discussing social or econ issues with diff confession"
lab var pre_q12_f_supervisor_REC1 "Supervised by diff confession"
lab var pre_q12_g_friends_REC1 "Friends with diff confession"
lab var pre_q7_a_friends_REC1 "Discuss issues"
lab var pre_q7_b_elites_REC1 "Talked to party members"
lab var pre_q7_c_petition_REC1 "Signed a petition"
lab var pre_q7_d_protest_REC1 "Attended protest"
lab var pre_q10_diffecon_REC1 "Friends from same class"
lab var pre_q5_diffsect_REC1 "Friends from same sect"
lab var pre_q4_changesect_REC1 "Willing to change sect"
lab var pre_q6_polparty_REC3b "Support sectarian political party"
lab var pre_q14_c_confession_REC1b "Strong sectarian identity"
lab var pre_q11_a_zaimhelp_REC1 "Help from zaim"
lab var pre_q11_b_relhelp_REC1 "Help from religious leader"
lab var index_connect_wgt4 "Well connected to sectarian elite"			
				
				
save "$data_orig/Leb_3_Clean_FINAL_Orig.dta", replace

