/*******************************************************************
REPLICATION FILE FOR:
Paper: "How Talking Across Ethnic and Class Divides Shapes Support for Ethnic Politics"
Authors: Laura Paler, Leslie Marshall, and Sami Atallah

This do file replicates all analysis in the main article and appendix.
Note that it is possible to run this do file on the "original" dataset as well
as on the "new" dataset (see the README file). Make sure the dataset you do not
want to use is commented out in the SETUP section below. 

You will also need to install two packages.

This do file calls Leb_5_RI, which performs the randomization inference in Online Appendix K.  
Before running, note that the randomization inference code takes about 3 hours per variable x 7 variables to complete.
********************************************************************/

*****************************************************************************************************************************************	
*SETUP	
*****************************************************************************************************************************************	
	
*Set your personal working directory here: cd~
cd ~/Dropbox/LEBANON/WRITING/2_DISCUSSION/REPLICATION

	global dos "DOs_and_ADOs"
	global packages "DOs_and_ADOs/PACKAGES"

	global data_orig "DATA/ORIG"
	global data_newimp "DATA/NEW_IMPUTE"
	global working "DATA/NEW_IMPUTE/WORKING"

	global results "RESULTS" 
	global results_figs "RESULTS/FIGS"
	global results_tables "RESULTS/TABLES"
	
	set more off

*Call the data actually used in the paper
	use "$data_orig/Leb_3_Clean_FINAL_Orig.dta", clear
	
	
*Call the dataset with the new missing data imputation
*	use "$data_newimp/Leb_3_Clean_NewImpute_FINAL.dta", clear
	
	
*Run the file that contains all author-written programs used in analysis	
	do "$dos/programs_xcut_FINAL.do"
	
	
*Installing version controlled packages
	do "$packages/grc1leg2.ado"
	do "$packages/randomize.ado"
	
*************************************************
*RUN MACROS NEEDED IN ANALYSIS
*************************************************
	
	global demo pre_q1_gender_REC2 pre_q2_age scr_q3_marital_REC2 scr_q4_educ_REC2 
	global demo_minus_gen pre_q2_age scr_q3_marital_REC2 scr_q4_educ_REC2 
	global sect pre_q3_christian pre_q3_sunni pre_q3_shia 
	global sect_minus_sun pre_q3_christian pre_q3_shia 
	global econ_id pre_q14_d_class_REC1b 
	global other_id pre_q14_leb_REC1b	
	global implement mod1 n_gid post_q7_knowppl_REC1 
	
	global econ_wgt1 index_econ_all_wgt1 scr_q6_work_REC1  
	global econ_wgt4 index_econ_all_wgt4 scr_q6_work_REC1  
	global econ_wgt6 index_econ_all_wgt6 scr_q6_work_REC1  
	
	global prej_wgt1 index_prej_wgt1 
	global prej_wgt4 index_prej_wgt4 
	global prej_wgt6 index_prej_wgt6 

	global act_wgt1 index_act_wgt1
	global act_wgt4 index_act_wgt4
	global act_wgt6 index_act_wgt6
	
	global networks_wgt1 index_soc_hom_wgt1 pre_q13_disagree_REC1 
	global networks_wgt4 index_soc_hom_wgt4 pre_q13_disagree_REC1 
	global networks_wgt6 index_soc_hom_wgt6 pre_q13_disagree_REC1 

	global sect_id_wgt1 index_sect_id_wgt1
	global sect_id_wgt4 index_sect_id_wgt4
	global sect_id_wgt6 index_sect_id_wgt6

	global connect_wgt1 index_connect_wgt1
	global connect_wgt4 index_connect_wgt4
	global connect_wgt6 index_connect_wgt6
	
*Main controls macros	
	global controls_all_wgt1 $demo_minus_gen $sect_minus_sun $econ_wgt1 $prej_wgt1 $act_wgt1 $networks_wgt1 $sect_id_wgt1 $connect_wgt1 $econ_id $other_id $implement 
	global controls_all_wgt4 $demo_minus_gen $sect_minus_sun $econ_wgt4 $prej_wgt4 $act_wgt4 $networks_wgt4 $sect_id_wgt4 $connect_wgt4 $econ_id $other_id $implement 
	global controls_all_wgt6 $demo_minus_gen $sect_minus_sun $econ_wgt6 $prej_wgt6 $act_wgt6 $networks_wgt6 $sect_id_wgt6 $connect_wgt6 $econ_id $other_id $implement 

	
*Index components
	global econ_all scr_q9_assets_REC1 scr_q10_hh_area scr_q11_summer_hh scr_q12_poweralt_code scr_q13_vacay_code scr_q14_dineout_REC1 scr_q15_income scr_q16_income_subj_REC1 pre_q8_income_REC1 pre_q9_class_REC3b 
	global sect_prej pre_q12_a_marry_REC1 pre_q12_b_doctor_REC1 pre_q12_c_neighbor_REC1 pre_q12_d_poltalk_REC1 pre_q12_e_econtalk_REC1 pre_q12_f_supervisor_REC1 pre_q12_g_friends_REC1 
	global act pre_q7_a_friends_REC1 pre_q7_b_elites_REC1 pre_q7_c_petition_REC1 pre_q7_d_protest_REC1 
	global soc_homog pre_q10_diffecon_REC1 pre_q5_diffsect_REC1
	global sect_id pre_q4_changesect_REC1 pre_q6_polparty_REC3b pre_q14_c_confession_REC1b	
	global connect pre_q11_a_zaimhelp_REC1 pre_q11_b_relhelp_REC1
	
	global index_components $econ_all $sect_prej $act $soc_homog $sect_id $connect 

	
*Main outcomes and mechanisms	
	global main_outs_all pet_allsign me_same_sect me_other_sect me_poor me_mid me_rich_nobeirut me_beirut_REC1 /// 
		me_same_poor me_other_poor me_same_mid me_other_mid me_same_rich me_other_rich post_q10_c_unsure_REC1b
	
	global main_mechs_all index_y_learn_shared_wgt4 index_y_learned_wgt4 post_q1_g_learned_REC1b post_q3_surprise_econ_REC1b /// 
		post_q5_surprise_sect_REC1b index_y_agree_wgt4 post_q2_simconcerns_REC1b post_q4_agreechange_REC1b ///
		q8_id_same_sect_same_class q8_id_same_sect_diff_class q8_id_diff_sect_same_class q8_id_diff_sect_diff_class ///
		q9_dist_same_sect_diff_class post_q9_diffsect_rich post_q9_diffsect_poor ///
		index_y_press_wgt4 post_q10_a_enemies_REC1b post_q10_b_worry_REC1b index_y_empathy_wgt4 post_q1_h_empthem_REC1b post_q1_i_empyou_REC1b post_q1_j_anxious_REC1

		
*****************************************************************************************************************************************	
*MAIN PAPER
*****************************************************************************************************************************************	

*************************************************
*FIGURE 1: PETITION RESULTS
*************************************************

*Petition results	
	eststo coefest1: mi estimate, post: areg pet_allsign group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid)

	coefplot (coefest1, label(Signed the petition) offset(0)), xline(0) keep(group2 group3 group4) ///
		coeflabel(group2 = "{bf:G2:} Mixed-sect, same-class" group3 = "{bf:G3:} Same-sect, mixed-class" group4 = "{bf:G4:} Mixed-sect, mixed-class", wrap(20)) ///
		title("") scheme(lean1) nokey grid(none) xscale(range(-.30 .30))  xlab(-.30(.05).30) symbol(circle) saving("$results_figs/main_coefplot_petition.gph", replace) 
	
	
*************************************************
*FIGURE 2: MAP RESULTS
*************************************************
	
	eststo coefest2: mi estimate, post: areg me_other_sect group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid)
	eststo coefest3: mi estimate, post: areg me_same_sect group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid)
	eststo coefest4: mi estimate, post: areg me_beirut_REC1 group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 
	eststo coefest5: mi estimate, post: areg me_poor group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid)
	eststo coefest6: mi estimate, post: areg me_same_poor group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid)
	eststo coefest7: mi estimate, post: areg me_other_poor group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 
	
	coefplot (coefest2, label(Share for non-cosect dist.) offset(.25)) (coefest3, label(Share for cosect dist.) offset(0)) (coefest4, label(Share for Beirut) offset(-.25)) ///
		, xline(0) keep(group2 group3 group4) ///
		coeflabel(group2 = "{bf:G2:} Mixed-sect, same-class" group3 = "{bf:G3:} Same-sect, mixed-class" group4 = "{bf:G4:} Mixed-sect, mixed-class", wrap(20)) ///
		title("") scheme(lean1) legend(position(6) region(style(outline))) title("Panel A") saving("$results_figs/main_coefplot_map1.gph", replace)
	
	coefplot ///
		(coefest5, label(Share for poor dist.) offset(.25)) (coefest6, label(Share for poor cosect dist.) offset(0)) ///
		(coefest7, label(Share for poor non-cosect dist.) offset(-.25)), xline(0) keep(group2 group3 group4) ///
		coeflabel(group2 = "{bf:G2:} Mixed-sect, same-class" group3 = "{bf:G3:} Same-sect, mixed-class" group4 = "{bf:G4:} Mixed-sect, mixed-class", wrap(20)) ///
		title("") scheme(lean1) legend(position(6)  region(style(outline))) title("Panel B") saving("$results_figs/main_coefplot_map2.gph", replace)
		
	
	graph combine "$results_figs/main_coefplot_map1.gph" "$results_figs/main_coefplot_map2.gph", col(2) row(1) graphregion(color(white)) xcommon saving("$results_figs/main_coefplot_map.gph", replace)
		
*************************************************
*FIGURE 3: LEARNING
*************************************************
	eststo coefest8:  mi estimate, post: areg index_y_learn_shared_wgt4 group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 
	eststo coefest9:  mi estimate, post: areg index_y_learned_wgt4      group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 
	eststo coefest10: mi estimate, post: areg index_y_agree_wgt4        group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 

	coefplot (coefest8, label(Learning about shared prefs index) offset(.25)) (coefest9, label(Learning index)) (coefest10, label(Shared prefs index) offset(-.25)) ///
		, xline(0) keep(group2 group3 group4) ///
		coeflabel(group2 = "{bf:G2:} Mixed-sect, same-class" group3 = "{bf:G3:} Same-sect, mixed-class" group4 = "{bf:G4:} Mixed-sect, mixed-class", wrap(20)) ///
		title("") scheme(lean1) legend(position(3) region(style(outline)))

	
	
*************************************************
*FIGURE 4: SOCIAL IDENTITY
*************************************************
	
	eststo coefest11: mi estimate, post: areg q8_id_same_sect_same_class group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 
	eststo coefest12: mi estimate, post: areg q8_id_diff_sect_same_class group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 
	eststo coefest13: mi estimate, post: areg q8_id_same_sect_diff_class group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 
	eststo coefest14: mi estimate, post: areg q8_id_diff_sect_diff_class group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid) 
			
	coefplot (coefest11, label(Cosectarians from own class) symbol(circle) offset(.35)) (coefest12, label(Non-cosectarians from own class) symbol(circle_hollow) offset(.10)) (coefest13, label(Cosectarians from other class) symbol(square) offset(-.10)) ///
		(coefest14, label(Non-cosectarians from other class) symbol(square_hollow) offset(-.35)) , xline(0) keep(group2 group3 group4) ///
		coeflabel(group2 = "{bf:G2:} Mixed-sect, same-class" group3 = "{bf:G3:} Same-sect, mixed-class" group4 = "{bf:G4:} Mixed-sect, mixed-class", wrap(20)) ///
		title("") scheme(lean1) legend(position(3) region(style(outline))) saving("$results_figs/main_coefplot_map.gph", replace)

			
*************************************************
*FIGURE 5: FEAR OF SOCIAL SANCTIONING
*************************************************

	eststo coefest18: mi estimate, post: areg index_y_press_wgt4 group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid)

	coefplot coefest18, xline(0) keep(group2 group3 group4) title("") ///
		coeflabel(group2 = "{bf:G2:} Mixed-sect, same-class" group3 = "{bf:G3:} Same-sect, mixed-class" group4 = "{bf:G4:} Mixed-sect, mixed-class", wrap(20)) ///
		title("") scheme(lean1) nokey grid(none) xscale(range(-.6 .6)) xlab(-.6(.2).6) symbol(circle)

	
*************************************************
*FIGURE 6: EMOTIONS
*************************************************
		
	eststo coefest19: mi estimate, post: areg index_y_empathy_wgt4 group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid)
	eststo coefest20: mi estimate, post: areg post_q1_j_anxious_REC1 group2 group3 group4 $controls_all_wgt4 [pweight=wgt4], absorb(strata_agg_FINAL2) vce(cluster gid)
	
	coefplot (coefest19, label(Empathy (index)) offset(.00)), xline(0) keep(group2 group3 group4) ///
		coeflabel(group2 = "{bf:G2:} Mixed-sect, same-class" group3 = "{bf:G3:} Same-sect, mixed-class" group4 = "{bf:G4:} Mixed-sect, mixed-class", wrap(20)) ///
		scheme(lean1) nokey grid(none) title("Empathy (index)") symbol(circle) saving("$results_figs/main_coefplot_empathy.gph", replace)
	
	coefplot (coefest20, label(Anxiety) offset(.00)), xline(0) keep(group2 group3 group4) ///
		coeflabel(group2 = "{bf:G2:} Mixed-sect, same-class" group3 = "{bf:G3:} Same-sect, mixed-class" group4 = "{bf:G4:} Mixed-sect, mixed-class", wrap(20)) ///
		scheme(lean1) nokey grid(none) title("Anxiety") symbol(circle) saving("$results_figs/main_coefplot_anxiety.gph", replace)

	
	graph combine "$results_figs/main_coefplot_empathy.gph" "$results_figs/main_coefplot_anxiety.gph", col(2) row(1) graphregion(color(white)) xcommon saving("$results_figs/main_coefplot_emotions.gph", replace)


	
*************************************************
*FIGURE 7: PGG RESULTS
*************************************************
	
*PRE POST CHANGE FIGURES (WITH AND WITHOUT GID=126)
preserve
est clear

eststo: mi estimate, post: reg pgg_rd1 group1 group2 group3 group4 [pweight=wgt4], nocons vce(cluster gid)
	predict y1, xb
	predict se1, stdp

eststo: mi estimate, post: reg pgg_rd2 group1 group2 group3 group4 [pweight=wgt4], nocons vce(cluster gid)
	predict y2, xb
	predict se2, stdp

keep group1 group2 group3 group4 y1 y2 pgg_rd1 pgg_rd2 wgt4 gid pid _mi_id _mi_miss _mi_m
	mi reshape long y, i(pid) j(round) 

twoway (connected y round if group1==1, lpattern(solid) symbol(circle_hollow)) ///
(connected y round if group2==1, lpattern(solid) symbol(circle)) ///
(connected y round if group3==1, lpattern(solid) symbol(square_hollow)) ///
(connected y round if group4==1, lpattern(solid) symbol(square)), ///
xlabel(1(1)2) xsc(r(0.6 2.4)) xlab(1 "Round 1" 2 "Round 2") xtitle("")  ///
ylabel(3000(100)4000) ytitle("Average Contribution") ///
scheme(lean1) title("Panel A: All groups") saving("$results_figs/pgg_all.gph", replace) ///
legend(label(1 "Same-sect, same-class") label(2 "Mixed-sect, same-class") label(3 "Same-sect, mixed-class") label(4 "Mixed-sect, mixed-class")) ///
legend(position(3) region(style(outline)))

restore

*WITHOUT GID=126
preserve
est clear

eststo: mi estimate, post: reg pgg_rd1 group1 group2 group3 group4 [pweight=wgt4] if gid!=126, nocons
	predict y1, xb
	predict se1, stdp

eststo: mi estimate, post: reg pgg_rd2 group1 group2 group3 group4 [pweight=wgt4] if gid!=126, nocons
	predict y2, xb
	predict se2, stdp

keep group1 group2 group3 group4 y1 y2 pgg_rd1 pgg_rd2 wgt4 gid pid _mi_id _mi_miss _mi_m
	mi reshape long y, i(pid) j(round) 

twoway (connected y round if group1==1, lpattern(solid) symbol(circle_hollow)) ///
(connected y round if group2==1, lpattern(solid) symbol(circle)) ///
(connected y round if group3==1, lpattern(solid) symbol(square_hollow)) ///
(connected y round if group4==1, lpattern(solid) symbol(square)), ///
xlabel(1(1)2) xsc(r(0.6 2.4)) xlab(1 "Round 1" 2 "Round 2") xtitle("")  ///
ylabel(3000(100)4000) ytitle("Average Contribution") ///
scheme(lean1) title("Panel B: Excluding outlier") saving("$results_figs/pgg_no126.gph", replace) ///
legend(label(1 "Same-sect, same-class") label(2 "Mixed-sect, same-class") label(3 "Same-sect, mixed-class") label(4 "Mixed-sect, mixed-class")) ///
legend(position(3) region(style(outline)))

restore

*Combine graphs
	grc1leg2 "$results_figs/pgg_all" "$results_figs/pgg_no126", graphregion(color(white)) saving("$results_figs/main_pgg.gph")
	

*****************************************************************************************************************************************	
*APPENDIX
*****************************************************************************************************************************************	
	
*******************************************************
*APPENDIX TABLE B.1: BALANCE CHECK
*Pre-treatment (pre-interaction) so do not cluster errors
*******************************************************


		
			
			
	est clear
		foreach var of varlist pre_q1_gender_REC2 $controls_all_wgt4 pre_q3_sunni $index_components {
			est clear
			eststo: mi estimate, post: mean `var' [pweight=wgt4] if T_mixed_sect==0 & T_mixed_class==0
			estout using "$results_tables/leb_diag_balance1.xls", cells(b(fmt(3))) append title(Group Means)

			est clear
			eststo: mi estimate, post: reg  `var'  group2 group3 group4 [pweight=wgt4], vce(robust)    
			estout using "$results_tables/leb_diag_balance1.xls", la append cells((b(fmt(%9.2f)) p(fmt(%9.3f)))) drop(_cons)  mlabels(`var') 
	}
	
*******************************************************
*APPENDIX TABLE D.1: COMPARISON OF OUR SAMPLE TO THE POPULATION
*******************************************************

	global disc_vars1 scr_q1_gender_REC2 pre_q2_age scr_q3_marital_REC2 scr_q4_educ_REC2 pre_q3_christian pre_q3_sunni pre_q3_shia 
	global disc_vars2 pre_q8_income_REC1 employed pre_q9_class_REC1b scr_q16_income_subj_REC1 concern_unemp_all concern_prices_all   
	global disc_vars3 pre_q11_a_zaimhelp_REC1 pre_q11_b_relhelp_REC1
	global disc_vars4 pre_q7_b_elites_REC1 pre_q7_c_petition_REC1 pre_q7_d_protest_REC1 
	global disc_vars5 pre_q12_a_marry_REC1 pre_q12_c_neighbor_REC1 pre_q12_f_supervisor_REC1 pre_q12_g_friends_REC1 
	global disc_vars6 pre_q5_diffsect_REC1 pre_q10_diffecon_REC1 pre_q13_disagree_REC1
	
	est clear
		estpost tabstat $disc_vars1 $disc_vars2 $disc_vars3 $disc_vars4 $disc_vars5 $disc_vars6  if m_impute==1, statistics(mean sd min max count) columns(statistics)
		esttab using "$results_tables/samp_v_pop1.csv", cells("mean sd min max count") nomtitle nonumber noobs replace l


*SUMMARY STATS FOR THE POPULATION	
preserve
	use "$data_orig/Leb_national_survey.dta", clear

	global surv_vars1 female age q30_married q31_educ_REC2 q33_christian q33_sunni q33_shia q35_sect_fut_REC1
	global surv_vars2 q69_hh_income_REC1 employed q71_econ_class_REC1b q70_subj_income_REC1 concern_unemp_all concern_prices_all
	global surv_vars3 q36_a_help_zaim_REC1 q36_b_help_rel_REC1
	global surv_vars4 q41_b_zaim q41_c_petition q41_d_protest
	global surv_vars5 q59_e_marry_REC1 q59_a_neighbors_REC1 q59_b_supervised_REC1 q59_c_friends_REC1 
	global surv_vars6 q43_sect_contact_REC1 q44_econ_contact_REC1 q45_debate
	
	
*Set the survey weight (options are wgt_main2a wgt_post2a wgt_ebal2)  	
	mi svyset id_psu [pweight=wgt_ebal2b]

*From Beirut/Mount Lebanon
	est clear
	scalar drop _all
	return clear
	ereturn clear
	foreach y of varlist $surv_vars1 $surv_vars2 $surv_vars3 $surv_vars4 $surv_vars5 $surv_vars6 {
		cap drop y2
		qui: mi xeq : generate y2 = `y'^2 
		eststo: mi est, esampvaryok post: svy: mean `y' y2 if mohafaza=="Beirut" | mohafaza=="Mount Lebanon" 
		estadd scalar meanUp = _b[`y']
		estadd scalar sdUp = sqrt( _b[y2] - _b[`y']^2 )
		estadd scalar nUp = (e(N))
		cap drop y2
	}
		
	esttab using "$results_tables/samp_v_pop2.csv", l replace scalar(meanUp sdUp nUp) sfmt(%9.2f %9.2f %9.0f) cells(none) noobs equations(1) mti($surv_vars1 $surv_vars2 $surv_vars3 $surv_vars4 $surv_vars5 $surv_vars6) wide 


*From whole country
	est clear
	scalar drop _all
	return clear
	ereturn clear
	foreach y of varlist $surv_vars1 $surv_vars2 $surv_vars3 $surv_vars4 $surv_vars5 $surv_vars6 {
		cap drop y2
		qui: mi xeq : generate y2 = `y'^2 
		eststo: mi est, esampvaryok post: svy: mean `y' y2 
		estadd scalar meanUp = _b[`y']
		estadd scalar sdUp = sqrt( _b[y2] - _b[`y']^2 )
		estadd scalar nUp = (e(N))
		cap drop y2
	}
		
	esttab using "$results_tables/samp_v_pop3.csv", l replace scalar(meanUp sdUp nUp) sfmt(%9.2f %9.2f %9.0f) cells(none) noobs equations(1) mti($surv_vars1 $surv_vars2 $surv_vars3 $surv_vars4 $surv_vars5 $surv_vars6) wide

	
*Descriptive stats on why people support sectarianism	
	
	mi estimate: mean q39_a_benefits_REC2 q39_b_econ_dev_REC2 q39_c_local_dev_REC2 q39_d_rep_govt_REC2 q39_e_leb_protect_REC2 q39_f_sect_protect_REC2 q39_g_sect_status_REC2 q39_h_stability_REC2 [pweight=wgt_ebal2b]
	
	tab q40_support_sect_REC1, g(q40_support_sect_dum)	
	
	eststo: mi estimate, esampvaryok post: mean q40_support_sect_dum* [pweight=wgt_ebal2b]
	
	
restore
 

*******************************************************
*APPENDIX G: SUMMARY STATS
*******************************************************
	
*APPENDIX TABLE G.1
	mi svyset gid [pweight=wgt4], strata(strata_agg_FINAL2) singleunit(centered) 

*Outcomes	
	est clear
	scalar drop _all
	return clear
	ereturn clear
	foreach y of varlist $main_mechs_all $main_outs_all post_q14_domidentity_REC1b {
		cap drop y2
		qui: mi xeq : generate y2 = `y'^2 
		eststo: mi est, esampvaryok post: svy: mean `y' y2 
		estadd scalar meanUp = _b[`y']
		estadd scalar sdUp = sqrt( _b[y2] - _b[`y']^2 )
		estadd scalar nUp = (e(N))
		cap drop y2
	}
		
	esttab using "$results_tables/dv_vars_descrip1.csv", l replace scalar(meanUp sdUp nUp) sfmt(%9.2f %9.2f %9.0f) cells(none) noobs equations(1) mti($main_mechs_all $main_outs_all) wide

	
*Get variable ranges and percentage missingness imputed	
	est clear
		estpost tabstat $main_mechs_all $main_outs_all post_q14_domidentity_REC1b if m_impute>0, statistics(min max count) columns(statistics)
		esttab using "$results_tables/dv_vars_descrip2.csv", cells("min max count") nomtitle nonumber noobs replace l

			
*APPENDIX TABLE G.2		
*Pre-treatment covariates
	mi svyset gid [pweight=wgt4], strata(strata_agg_FINAL2) singleunit(centered) 
	
	est clear
	scalar drop _all
	return clear
	ereturn clear
	foreach y of varlist pre_q1_gender_REC2 $controls_all_wgt4 pre_q3_sunni $index_components {
		cap drop y2
		qui: mi xeq : generate y2 = `y'^2 
		eststo: mi est, esampvaryok post: svy: mean `y' y2 
		estadd scalar meanUp = _b[`y']
		estadd scalar sdUp = sqrt( _b[y2] - _b[`y']^2 )
		estadd scalar nUp = (e(N))
		cap drop y2
	}
		
	esttab using "$results_tables/covars_descrip1.csv", label replace scalar(meanUp sdUp nUp) sfmt(%9.2f %9.2f %9.0f) cells(none) noobs equations(1) mti($controls_all_wgt4 pre_q3_sunni $index_components)

*Get variable ranges and percentage missingness imputed	
	est clear
		estpost tabstat pre_q1_gender_REC2 $controls_all_wgt4 pre_q3_sunni $index_components if m_impute>0, statistics(min max count) columns(statistics)
		esttab using "$results_tables/covars_descrip2.csv", cells("min max count") nomtitle nonumber noobs replace l

*******************************************************
*APPENDIX TABLE H.1: PARTICIPANT PRIORITIES
*******************************************************
	
*All policy priorities listed as among top three concerns
	local concerns_all_econ concern_unemp_all concern_prices_all concern_poverty_all concern_costs_all concern_deficit_all concern_ineq_all concern_food_all concern_electric_all concern_manu_all concern_transport_all concern_locdev_all concern_oil_all
	local concerns_all_pol concern_terror_all concern_war_all concern_sect_all concern_garbage_all concern_weapons_all concern_corrupt_all concern_crime_all concern_groups_all concern_radic_all concern_israel_all concern_instab_all concern_elect_all concern_judic_all 
	

*Obtain means by class and confession	
	est clear
	
	foreach var of varlist `concerns_all_econ' `concerns_all_pol' {
		eststo: mi estimate, post: mean `var'
		eststo: mi estimate, post: mean `var', over(class_confess)
		
	}
	
	estout using "$results_tables/test1.xls", mlab(`concerns_all_econ' `concerns_all_pol') replace
	
	
*Obtain means and standard deviations by class	
	est clear
	scalar drop _all
	return clear
	ereturn clear
	foreach y of varlist `concerns_all_econ' `concerns_all_pol' {
		cap drop y2
		qui: mi xeq : generate y2 = `y'^2 
		eststo: mi est, esampvaryok post: mean `y' y2 if poor==1
		estadd scalar meanUp = _b[`y']
		estadd scalar sdUp = sqrt( _b[y2] - _b[`y']^2 )
		estadd scalar nUp = (e(N))
		cap drop y2
	}
	esttab using "$results_tables/leb_priorities_poor.csv", l replace scalar(meanUp sdUp) sfmt(%9.2f %9.2f) cells(none) noobs equations(1) mti(`concerns_all_econ' `concerns_all_pol') wide

	est clear
	scalar drop _all
	return clear
	ereturn clear
	foreach y of varlist `concerns_all_econ' `concerns_all_pol' {
		cap drop y2
		qui: mi xeq : generate y2 = `y'^2 
		eststo: mi est, esampvaryok post: mean `y' y2 if rich==1
		estadd scalar meanUp = _b[`y']
		estadd scalar sdUp = sqrt( _b[y2] - _b[`y']^2 )
		estadd scalar nUp = (e(N))
		cap drop y2
	}
	esttab using "$results_tables/leb_priorities_rich.csv", l replace scalar(meanUp sdUp) sfmt(%9.2f %9.2f) cells(none) noobs equations(1) mti(`concerns_all_econ' `concerns_all_pol') wide
	
	
*Test differences in means by class	

	
	est clear
	foreach var of varlist `concerns_all_econ' `concerns_all_pol' {
		eststo: mi estimate, post: reg `var' rich
		estout using "$results_tables/leb_priorities_test1.xls", la append cells("b(fmt(%9.2f)) p(fmt(%9.3f))")  mlab(`concerns_all_econ' `concerns_all_pol') 
	}

	
*******************************************************
*APPENDIX I: WHAT WAS DISCUSSED? (MODERATOR SURVEY)
*******************************************************
	
	local econ_concerns ms_q30_corrupt ms_q30_immigration ms_q30_security ms_q30_infra ms_q30_econ ms_q30_jobs ms_q30_food ms_q30_prices ms_q30_water ms_q30_electric ms_q30_educ ms_q30_housing ms_q30_healthcare ms_q30_soc_serv
	local pol_concerns ms_q36_statusquo ms_q36_noagree ms_q36_nohope ms_q36_endsect ms_q36_regime ms_q36_leaders ms_q36_elect ms_q36_govern ms_q36_econ ms_q36_social ms_q36_security

	
*Likelihood that an econ topic came up (mentioned in text)	
	est clear
	
	foreach var of varlist `econ_concerns'  {
		eststo: mean `var' if tag_gid==1 & m_impute==1    		
		eststo: mean `var' if tag_gid==1 & m_impute==1, over(T_mixed_sect T_mixed_class)    		
	
	}
	
	estout using "$results_tables/xcut_mod_shared_econ.xls", cells(b(fmt(3))) replace title(Group Means)

	
*APPENDIX TABLE I.1: Perceptions of shared econ preferences	
	est clear
	foreach var of varlist `econ_concerns' {
		est clear
		eststo:  mi estimate, post: areg `var' group2 group3 group4 mod if tag_gid==1, absorb(set)       
	estout using "$results_tables/xcut_mod_shared_econ.xls", la append cells(b(fmt(%9.2f) star) se(par(`"="("'`")""') fmt(%9.2f)) p(fmt(%9.3f))) keep(group*) starl(* .10 ** .05  *** .01) stats(N)  mlabels(`var') 
	}
	
	
*Likelihood that political topic came up	
	est clear
	
	foreach var of varlist `pol_concerns'  {
		eststo: mean `var' if tag_gid==1 & m_impute==1    		
		eststo: mean `var' if tag_gid==1 & m_impute==1, over(T_mixed_sect T_mixed_class)    		
	}
	
	
	estout using "$results_tables/xcut_mod_shared_pol.xls", cells(b(fmt(3))) replace title(Group Means)

*APPENDIX TABLE I.2: Perceptions of shared political preferences
	est clear
	foreach var of varlist `pol_concerns' {
		est clear
		eststo:  mi estimate, post: areg `var' group2 group3 group4 mod 	if tag_gid==1, absorb(set)       
	estout using "$results_tables/xcut_mod_shared_pol.xls", la append cells(b(fmt(%9.2f) star) se(par(`"="("'`")""') fmt(%9.2f)) p(fmt(%9.3f))) keep(group*) starl(* .10 ** .05  *** .01) stats(N)  mlabels(`var') 
	}
	

*************************************************
*APPENDIX J: MAIN RESULTS TABLES
*************************************************
	
*APPENDIX TABLE J.1: MAIN RESULTS
	
*Petition	
	leb_xcut_group pet_allsign
	
*Main map	
	leb_xcut_group me_same_sect
	leb_xcut_group me_other_sect
	leb_xcut_group me_beirut_REC1
	leb_xcut_group me_poor
	leb_xcut_group me_same_poor
	leb_xcut_group me_other_poor

*Additional map	
	leb_xcut_group me_mid
	leb_xcut_group me_same_mid
	leb_xcut_group me_other_mid
	leb_xcut_group me_rich_nobeirut
	leb_xcut_group me_same_rich
	leb_xcut_group me_other_rich
	
	
*Uncertainty	
	leb_xcut_group post_q10_c_unsure_REC1b


*APPENDIX TABLE J.2: MECHANISMS	
	
*Learning	
	leb_xcut_group index_y_learn_shared_wgt4

	leb_xcut_group index_y_learned_wgt4 
		leb_xcut_group post_q1_g_learned_REC1b 
		leb_xcut_group post_q3_surprise_econ_REC1b 
		leb_xcut_group post_q5_surprise_sect_REC1b 
	
	leb_xcut_group index_y_agree_wgt4
		leb_xcut_group post_q2_simconcerns_REC1b
		leb_xcut_group post_q4_agreechange_REC1b 

*Identity		
	leb_xcut_group q8_id_same_sect_same_class
	leb_xcut_group q8_id_same_sect_diff_class 
	leb_xcut_group q8_id_diff_sect_same_class
	leb_xcut_group q8_id_diff_sect_diff_class

	leb_xcut_group q9_dist_same_sect_diff_class
	leb_xcut_group post_q9_diffsect_rich
	leb_xcut_group post_q9_diffsect_poor
		
*Lebanese identity	
	leb_xcut_group post_q14_domidentity_REC1b


*Pressure	
	leb_xcut_group index_y_press_wgt4 	
		leb_xcut_group post_q10_a_enemies_REC1b 
		leb_xcut_group post_q10_b_worry_REC1b 

*Emotions	
	leb_xcut_group index_y_empathy_wgt4
		leb_xcut_group post_q1_h_empthem_REC1b 
		leb_xcut_group post_q1_i_empyou_REC1b
	
	leb_xcut_group post_q1_j_anxious_REC1


*************************************************
*APPENDIX J.2: INTERACTION RESULTS
*************************************************
	
*APPENDIX TABLE J.3
	leb_xcut_int pet_allsign
	leb_xcut_int me_other_sect
	leb_xcut_int me_same_sect
	leb_xcut_int me_beirut_REC1
	leb_xcut_int me_poor
	leb_xcut_int me_same_poor
	leb_xcut_int me_other_poor
	
*APPENDIX TABLE J.4	
	leb_xcut_int index_y_learn_shared_wgt4
	leb_xcut_int index_y_learned_wgt4 
	leb_xcut_int index_y_agree_wgt4
	leb_xcut_int q8_id_same_sect_same_class
	leb_xcut_int q8_id_diff_sect_same_class
	leb_xcut_int q8_id_same_sect_diff_class
	leb_xcut_int q8_id_diff_sect_diff_class
	leb_xcut_int index_y_press_wgt4
	leb_xcut_int index_y_empathy_wgt4
	leb_xcut_int post_q1_j_anxious_REC1

*************************************************
*APPENDIX J.3: ADDITIONAL PGG ANALYSIS
*************************************************


*APPENDIX TABLE J.5
*ALL GROUPS
*Effects round 1	
	leb_xcut_group pgg_rd1
	eststo: mi estimate, cmdok post: leb_xcut_margins pgg_rd1
	
*Effects round2
	leb_xcut_group pgg_rd2
	eststo: mi estimate, cmdok post: leb_xcut_margins pgg_rd2
	
*Effects diff	
	leb_xcut_group pgg_diff
	eststo: mi estimate, cmdok post: leb_xcut_margins pgg_diff
	
*Note: Running the code below w/o GID==126 overwrites the .xls file from the all groups code	
*WITHOUG GID=126	
	leb_xcut_group pgg_rd1 if gid!=126
	eststo: mi estimate, cmdok post: leb_xcut_margins pgg_rd1 if gid!=126
	
*Effects round2
	leb_xcut_group pgg_rd2 if gid!=126
	eststo: mi estimate, cmdok post: leb_xcut_margins pgg_rd2 if gid!=126
	
*Effects diff	
	leb_xcut_group pgg_diff if gid!=126
	eststo: mi estimate, cmdok post: leb_xcut_margins pgg_diff if gid!=126
	
	
*APPENDIX FIGURE J.1: Contributions by GID	
	graph twoway bar mean_pgg_rd1_g1 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(0 10000)) ylab(0(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3)) ///
		subtitle("Same sect, same class") name("pgg_rd1_g1", replace) ///
			|| function y = 3341.472 , range(0 31) legend(off) ylab(3341, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
		
	graph twoway bar mean_pgg_rd1_g2 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(0 10000)) ylab(0(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Mixed sect, same class") name("pgg_rd1_g2", replace) ///
			|| function y = 3709.466 , range(0 31) legend(off) ylab(3709, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)

	graph twoway bar mean_pgg_rd1_g3 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(0 10000)) ylab(0(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Same sect, mixed class") name("pgg_rd1_g3", replace) ///
			|| function y = 3949.875 , range(0 31) legend(off) ylab(3950, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
	
	graph twoway bar mean_pgg_rd1_g4 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(0 10000)) ylab(0(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Mixed sect, mixed class") name("pgg_rd1_g4", replace) ///
			|| function y = 3096.21 , range(0 31) legend(off) ylab(3096, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
	
	graph combine pgg_rd1_g1 pgg_rd1_g2 pgg_rd1_g3 pgg_rd1_g4, title("Public Goods Game: Round 1") graphregion(color(white))

*Round 2 contributions bar graphs
	graph twoway bar mean_pgg_rd2_g1 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(0 10000)) ylab(0(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3)) ///
		subtitle("Same sect, same class") name("pgg_rd2_g1", replace) ///
			|| function y = 3612.514 , range(0 31) legend(off) ylab(3612, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
		
	graph twoway bar mean_pgg_rd2_g2 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(0 10000)) ylab(0(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Mixed sect, same class") name("pgg_rd2_g2", replace) ///
			|| function y = 3524.911 , range(0 31) legend(off) ylab(3524, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)

	graph twoway bar mean_pgg_rd2_g3 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(0 10000)) ylab(0(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Same sect, mixed class") name("pgg_rd2_g3", replace) ///
			|| function y = 3844.375 , range(0 31) legend(off) ylab(3844, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
	
	graph twoway bar mean_pgg_rd2_g4 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(0 10000)) ylab(0(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Mixed sect, mixed class") name("pgg_rd2_g4", replace) ///
			|| function y = 3044.96 , range(0 31) legend(off) ylab(3044, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
	
	graph combine pgg_rd2_g1 pgg_rd2_g2 pgg_rd2_g3 pgg_rd2_g4, title("Public Goods Game: Round 2") graphregion(color(white))
	
*APPENDIX FIGURE J.2: Difference between rounds bar graphs
	graph twoway bar mean_pgg_diff_g1 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(-3000 10000)) ylab(-3000(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3)) ///
		subtitle("Same sect, same class") name("pgg_diff_g1", replace) ///
			|| function y = 271 , range(0 31) legend(off) ylab(271, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
		
	graph twoway bar mean_pgg_diff_g2 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(-3000 10000)) ylab(-3000(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Mixed sect, same class") name("pgg_diff_g2", replace) ///
			|| function y = -184 , range(0 31) legend(off) ylab(-184, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)

	graph twoway bar mean_pgg_diff_g3 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(-3000 10000)) ylab(-3000(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Same sect, mixed class") name("pgg_diff_g3", replace) ///
			|| function y = -105 , range(0 31) legend(off) ylab(-105, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
	
	graph twoway bar mean_pgg_diff_g4 order_in_gid [pweight=wgt4], ///
		  scheme(lean1) xlab(1(1)30, labsize(tiny)) barw(0.6) ///
		yaxis(1 2) yscale(range(-3000 10000)) ylab(-3000(1000)10000, labsize(tiny) axis(1) grid) ///
		ytitle("Contributions(mean)", size(3))  ///
		subtitle("Mixed sect, mixed class") name("pgg_diff_g4", replace) ///
			|| function y = -51 , range(0 31) legend(off) ylab(-51, ///
			axis(2) labsize(small)) lcolor(red) lstyle(solid)
	
	graph combine pgg_diff_g1 pgg_diff_g2 pgg_diff_g3 pgg_diff_g4, title("Public Goods Game: Difference Between Rounds") graphregion(color(white))

*APPENDIX FIGURE J.3: HISTOGRAMS OF CONTRIBUTIONS
	hist pgg_rd1 if m_impute==1, by(final_assign) scheme(lean1) bin(10) percent		
	
	hist pgg_rd2 if m_impute==1, by(final_assign) scheme(lean1) bin(10) percent		
	
	
*APPENDIX FIGURE J.4: HISTOGRAM OF DIFFERENCE IN CONTRIBUTIONS	
	hist pgg_diff if m_impute==1, by(final_assign) scheme(lean1) bin(25) percent xlab(-10000(2000)10000, labsize(tiny)) ylab(0(10)80, grid) xtitle("Difference in Contributions")		
	
	
*************************************************
*APPENDIX K: ROBUSTNESS CHECKS
*************************************************

*APPENDIX TABLE K.2	
	leb_xcut_robust pet_allsign	

*APPENDIX TABLE K.3		
	leb_xcut_robust me_same_sect
	leb_xcut_robust me_other_sect
	leb_xcut_robust me_beirut_REC1
	
	leb_xcut_robust me_poor
	leb_xcut_robust me_same_poor
	leb_xcut_robust me_other_poor

*APPENDIX TABLE K.4
	leb_xcut_robust index_y_learn_shared_wgt4	
	leb_xcut_robust index_y_learned_wgt4 
	leb_xcut_robust index_y_agree_wgt4
	
*APPENDIX TABLE K.5	
	leb_xcut_robust q8_id_same_sect_same_class
	leb_xcut_olog q8_id_same_sect_same_class

	leb_xcut_robust q8_id_same_sect_diff_class 
	leb_xcut_olog q8_id_same_sect_diff_class 

	leb_xcut_robust q8_id_diff_sect_same_class
	leb_xcut_olog q8_id_diff_sect_same_class
	
	leb_xcut_robust q8_id_diff_sect_diff_class
	leb_xcut_olog q8_id_diff_sect_diff_class
	
	
*APPENDIX TABLE K.6	
	leb_xcut_robust index_y_press_wgt4		
	leb_xcut_robust index_y_empathy_wgt4
	leb_xcut_robust post_q1_j_anxious_REC1


	
*******************************************************
*APPENDIX K.2: RANDOMIZATION INFERENCE
*See the separate do file included with the replication		
*******************************************************
		
	do "$dos/Leb_5_RI.do"

*******************************************************
*APPENDIX L: HETEROGENEOUS EFFECTS		
*******************************************************

*CLASS
*APPENDIX TABLE L.1: Main Outcomes
	global outcomes_up   pet_allsign me_beirut_REC1 me_poor 
	global het_up 		 poor
	global var_out 		 index_econ_all_wgt4 
	leb_xcut_het


*APPENDIX TABLE L.2: Mechanisms	1
	global outcomes_up   index_y_learn_shared_wgt4 q8_id_diff_sect_same_class q8_id_same_sect_diff_class
	global het_up 		 poor
	global var_out 		 index_econ_all_wgt4 
	leb_xcut_het
	
	
*APPENDIX TABLE L.3: Mechanism 2	
	global outcomes_up   index_y_press_wgt4 index_y_empathy_wgt4 post_q1_j_anxious_REC1
	global het_up 		 poor
	global var_out 		 index_econ_all_wgt4 
	leb_xcut_het

	
*SECT	
*APPENDIX TABLE L.4: Main Outcomes
	global outcomes_up   pet_allsign me_beirut_REC1 me_poor 
	global het_up 		 pre_q3_christian pre_q3_shia pre_q3_sunni
	global var_out 		 pre_q3_christian pre_q3_shia pre_q3_sunni
	leb_xcut_het


*APPENDIX TABLE L.5: Mechanisms	1
	global outcomes_up   index_y_learn_shared_wgt4 q8_id_diff_sect_same_class q8_id_same_sect_diff_class
	global het_up 		 pre_q3_christian pre_q3_shia pre_q3_sunni
	global var_out 		 pre_q3_christian pre_q3_shia pre_q3_sunni
	leb_xcut_het

	
*APPENDIX TABLE L.6: Mechanism 2	
	global outcomes_up   index_y_press_wgt4 index_y_empathy_wgt4 post_q1_j_anxious_REC1
	global het_up 		 pre_q3_christian pre_q3_shia pre_q3_sunni
	global var_out 		 pre_q3_christian pre_q3_shia pre_q3_sunni
	leb_xcut_het



*APPENDIX TABLE L.7: NETWORK HOMOGENEITY	
	unab varlist  : $controls_all_wgt4
	unab drop_var : index_soc_hom_wgt4
	local newlist : list varlist - drop_var
	
	capture program drop leb_het_netw
	program leb_het_netw, eclass properties(mi)
		args DV group hetvar
		version 14
			areg `DV' `group'##het_netw `newlist' [pweight=wgt4], vce(cluster gid) absorb(strata_agg_FINAL2)  
			margins, dydx(`group') at(het_netw=(1 2 3 4)) atmeans post
			eststo margins
	end
	
	foreach var of varlist pet_allsign me_beirut_REC1 me_poor index_y_learn_shared_wgt4 index_y_agree_wgt4 q8_id_diff_sect_same_class q8_id_same_sect_diff_class index_y_press_wgt4 index_y_empathy_wgt4 post_q1_j_anxious_REC1 {
		est clear
		foreach group in group2 group3 group4 {
				eststo: mi estimate, cmdok post: leb_het_netw `var' `group'
			}
		estout using "$results_tables/leb_het_netw_`var'.xls", replace cells(b(fmt(%9.2f) star) se(par(`"="("'`")""') fmt(%9.2f)) p(fmt(%9.3f))) starl(* .10 ** .05  *** .01) noomitted nobaselevels 
	}
	
